"""杂项实体类"""
from .friend import *


class Comment(object):
    """评论实体类"""
    pass


class Traffic(object):
    """流量实体类"""

    like_count: int = None
    """点赞数"""

    likers: list[User] = None
    """点赞人列表"""

    view_count: int = None
    """浏览数"""

    forward_count: int = None
    """转发数"""

    forwarders: list[User] = None
    """转发人列表"""

    comment_count: int = None
    """评论数"""

    comments: list[Comment] = None
    """评论列表"""


class Feed(object):
    """动态基类"""

    timestamp: int = None
    """动态时间戳"""

    user: User = None
    """动态发表人"""

    traffic: Traffic = None
    """动态流量"""



from pyqzone.entities import emotion
from ..model import AbstractEmotionAPIGroup


class WebEmotionAPI(AbstractEmotionAPIGroup):
    """PCWeb端的说说API组"""
    
    def fetch_feeds(self, page: int, **kwargs) -> list[emotion.Feed]:
        pass


from abc import ABC, abstractmethod
from ..entities import emotion
from ..client.model import AbstractClient


class AbstractAPIGroup(ABC):
    """分类API基类"""

    api_host: 'AbstractAPIHost' = None
    """API宿主"""

    def __init__(self, api_host: 'AbstractAPIHost'):
        self.api_host = api_host

    @property
    def host(self):
        return self.api_host


class AbstractEmotionAPIGroup(AbstractAPIGroup):
    """说说相关API组"""
    
    @abstractmethod
    def fetch_feeds(
        self,
        page: int,
        **kwargs
    ) -> list[emotion.Feed]:
        pass


class AbstractBlogAPIGroup(AbstractAPIGroup):
    """日志相关API组"""
    pass


class AbstractAlbumAPIGroup(AbstractAPIGroup):
    """相册相关API组"""
    pass


class AbstractBoardAPIGroup(AbstractAPIGroup):
    """留言板相关API组"""
    pass


class AbstractProfileAPIGroup(AbstractAPIGroup):
    """个人信息相关API组"""
    pass


class AbstractFriendAPIGroup(AbstractAPIGroup):
    """好友信息相关API组"""
    pass

class AbstractAPIHost(ABC):
    """API宿主类"""

    client: AbstractClient

    emotion: AbstractEmotionAPIGroup
    """说说API"""

    blog: AbstractBlogAPIGroup
    """日志API"""

    album: AbstractAlbumAPIGroup
    """相册API"""

    board: AbstractBoardAPIGroup
    """留言板API"""

    profile: AbstractProfileAPIGroup
    """个人信息API"""

    friend: AbstractFriendAPIGroup
    """好友信息API"""
    


from ..model import *
from .emotion import *
from .blog import *
from .album import *
from .board import *
from .profile import *
from .friend import *

from ...client.web.host import WebClient

class WebAPIHost(AbstractAPIHost):
    
    def __init__(self, client: WebClient):
        self.emotion = WebEmotionAPI(self)
        self.blog = WebBlogAPI(self)
        self.album = WebAlbumAPI(self)
        self.board = WebBoardAPI(self)
        self.profile = WebProfileAPI(self)
        self.friend = WebFriendAPI(self)


from abc import ABC, abstractmethod
from ..api.model import AbstractAPIHost


class AbstractClient(ABC):

    api_host: AbstractAPIHost = None

    @abstractmethod
    def login(self, *args, **kwargs):
        pass

    @property
    def api(self):
        return self.api_host
    